pub struct PrivateAccountV3Api {
pub vcoin_name: String,
pub coin_id: String,
pub balance_amount: String,
pub balance_amount_change: String,
pub frozen_amount: String,
pub frozen_amount_change: String,
pub type: String,
pub time: i64,
}Fields
vcoin_name: Stringcoin_id: Stringbalance_amount: Stringbalance_amount_change: Stringfrozen_amount: Stringfrozen_amount_change: Stringtype: Stringtime: i64Trait Implementations
Sourceimpl Clone for PrivateAccountV3Api
impl Clone for PrivateAccountV3Api
Sourcefn clone(&self) -> PrivateAccountV3Api
fn clone(&self) -> PrivateAccountV3Api
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrivateAccountV3Api
impl Debug for PrivateAccountV3Api
Sourceimpl Default for PrivateAccountV3Api
impl Default for PrivateAccountV3Api
Sourceimpl<'de> Deserialize<'de> for PrivateAccountV3Api
impl<'de> Deserialize<'de> for PrivateAccountV3Api
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for PrivateAccountV3Api
impl Message for PrivateAccountV3Api
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PrivateAccountV3Api
impl PartialEq for PrivateAccountV3Api
Sourcefn eq(&self, other: &PrivateAccountV3Api) -> bool
fn eq(&self, other: &PrivateAccountV3Api) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PrivateAccountV3Api
impl Serialize for PrivateAccountV3Api
impl StructuralPartialEq for PrivateAccountV3Api